@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, List, Optional, cast
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -22,7 +23,11 @@ class Edge:
         node_ids = self.node_ids
 
         dct = {
-            "node_ids": node_ids,
+            k: v
+            for k, v in {
+                "node_ids": node_ids,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
