@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional
 import attr
 
 from ..models.client_application import ClientApplication
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -20,7 +21,11 @@ class ListClientApplicationsResponse:
             client_applications.append(client_applications_item)
 
         dct = {
-            "clientApplications": client_applications,
+            k: v
+            for k, v in {
+                "clientApplications": client_applications,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
