@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, Optional
 import attr
 
 from ..models.user_credentials_password import UserCredentialsPassword
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -16,7 +17,11 @@ class UserCredentials:
         password = self.password.to_dict()
 
         dct = {
-            "password": password,
+            k: v
+            for k, v in {
+                "password": password,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
