@@ -2,6 +2,7 @@ from typing import Any, Callable, Dict, Optional
 
 import attr
 
+from ..types import UNSET
 from ..util.serialization import is_not_none
 
 
@@ -21,10 +22,14 @@ class UserProfile:
         organization = self.organization
 
         dct = {
-            "email": email,
-            "firstName": first_name,
-            "lastName": last_name,
-            "organization": organization,
+            k: v
+            for k, v in {
+                "email": email,
+                "firstName": first_name,
+                "lastName": last_name,
+                "organization": organization,
+            }.items()
+            if v != UNSET
         }
         if pick_by_predicate is not None:
             dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
